# Generated by Django 4.1.3 on 2023-01-20 10:26

from django.db import migrations
import multiselectfield.db.fields


class Migration(migrations.Migration):

    dependencies = [
        ('organizations', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='organization',
            name='networks',
            field=multiselectfield.db.fields.MultiSelectField(choices=[('AlastriaDefaultName', 'Alastria'), ('LacchainDefaultName', 'Lacchain')], default=1, max_length=19),
            preserve_default=False,
        ),
    ]
